@@ -37,28 +37,40 @@ class EditorFrame(ttk.Frame):
 
         # Toolbar.
         self.top_bar = ttk.Frame(self.master)
-        self.open_btn = ttk.Button(self.top_bar, text="Open", command=self.open_md_file)
+
+        self.open_icon = ttk.PhotoImage(file="pymd_editor/icons/round_file_open_black_24dp.png")
+        self.open_btn = ttk.Button(self.top_bar, text="Open", command=self.open_md_file, image=self.open_icon)
         self.open_btn.pack(side="left", padx=0, pady=0)
-        self.save_as_btn = ttk.Button(self.top_bar, text="Save As", command=self.save_as_md_file)
+        self.save_as_icon = ttk.PhotoImage(file="pymd_editor/icons/round_save_as_black_24dp.png")
+        self.save_as_btn = ttk.Button(self.top_bar, text="Save As", command=self.save_as_md_file, image=self.save_as_icon)
         self.save_as_btn.pack(side="left", padx=0, pady=0)
-        self.save_btn = ttk.Button(self.top_bar, text="Save", command=self.save_md_file)
+        self.save_icon = ttk.PhotoImage(file="pymd_editor/icons/round_save_black_24dp.png")
+        self.save_btn = ttk.Button(self.top_bar, text="Save", command=self.save_md_file, image=self.save_icon)
         self.save_btn.pack(side="left", padx=0, pady=0)
-        self.undo_btn = ttk.Button(self.top_bar, text="Undo", command=lambda: self.text_area.event_generate("<<Undo>>"))
+        self.undo_icon = ttk.PhotoImage(file="pymd_editor/icons/round_undo_black_24dp.png")
+        self.undo_btn = ttk.Button(self.top_bar, text="Undo", command=lambda: self.text_area.event_generate("<<Undo>>"), image=self.undo_icon)
         self.undo_btn.pack(side="left", padx=0, pady=0)
-        self.redo_btn = ttk.Button(self.top_bar, text="Redo", command=lambda: self.text_area.event_generate("<<Redo>>"))
+        self.redo_icon = ttk.PhotoImage(file="pymd_editor/icons/round_redo_black_24dp.png")
+        self.redo_btn = ttk.Button(self.top_bar, text="Redo", command=lambda: self.text_area.event_generate("<<Redo>>"), image=self.redo_icon)
         self.redo_btn.pack(side="left", padx=0, pady=0)
-        self.cut_btn = ttk.Button(self.top_bar, text="Cut", command=lambda: self.text_area.event_generate("<<Cut>>"))
+        self.cut_icon = ttk.PhotoImage(file="pymd_editor/icons/round_content_cut_black_24dp.png")
+        self.cut_btn = ttk.Button(self.top_bar, text="Cut", command=lambda: self.text_area.event_generate("<<Cut>>"), image=self.cut_icon)
         self.cut_btn.pack(side="left", padx=0, pady=0)
-        self.copy_btn = ttk.Button(self.top_bar, text="Copy", command=lambda: self.text_area.event_generate("<<Copy>>"))
+        self.copy_icon = ttk.PhotoImage(file="pymd_editor/icons/round_file_copy_black_24dp.png")
+        self.copy_btn = ttk.Button(self.top_bar, text="Copy", command=lambda: self.text_area.event_generate("<<Copy>>"), image=self.copy_icon)
         self.copy_btn.pack(side="left", padx=0, pady=0)
-        self.paste_btn = ttk.Button(self.top_bar, text="Paste", command=lambda: self.text_area.event_generate("<<Paste>>"))
+        self.paste_icon = ttk.PhotoImage(file="pymd_editor/icons/round_content_paste_black_24dp.png")
+        self.paste_btn = ttk.Button(self.top_bar, text="Paste", command=lambda: self.text_area.event_generate("<<Paste>>"), image=self.paste_icon)
         self.paste_btn.pack(side="left", padx=0, pady=0)
-        self.find_btn = ttk.Button(self.top_bar, text="Find", command=self.find)
+        self.find_icon = ttk.PhotoImage(file="pymd_editor/icons/round_find_in_page_black_24dp.png")
+        self.find_btn = ttk.Button(self.top_bar, text="Find", command=self.find, image=self.find_icon)
         self.find_btn.pack(side="left", padx=0, pady=0)
-        # self.bold_btn = ttk.Button(self.top_bar, text="Bold", command=self.bold)
-        # self.bold_btn.pack(side="left", padx=0, pady=0)
-        # self.italic_btn = ttk.Button(self.top_bar, text="Italic")
-        # self.italic_btn.pack(side="left", padx=0, pady=0)
+        self.bold_icon = ttk.PhotoImage(file="pymd_editor/icons/round_format_bold_black_24dp.png")
+        self.bold_btn = ttk.Button(self.top_bar, text="Bold", command=lambda: self.apply_markdown_both_sides(constants.bold_md_syntax, constants.bold_md_ignore), image=self.bold_icon)
+        self.bold_btn.pack(side="left", padx=0, pady=0)
+        self.italic_icon = ttk.PhotoImage(file="pymd_editor/icons/round_format_italic_black_24dp.png")
+        self.italic_btn = ttk.Button(self.top_bar, text="Italic", command=lambda: self.apply_markdown_both_sides(constants.italic_md_syntax, constants.italic_md_ignore), image=self.italic_icon)
+        self.italic_btn.pack(side="left", padx=0, pady=0)
         # self.bold_italic_btn = ttk.Button(self.top_bar, text="Bold Italic")
         # self.bold_italic_btn.pack(side="left", padx=0, pady=0)
         # self.heading_btn = ttk.Button(self.top_bar, text="Heading")
@@ -81,6 +93,54 @@ class EditorFrame(ttk.Frame):
         # self.link_btn.pack(side="left", padx=0, pady=0)
         # self.image_btn = ttk.Button(self.top_bar, text="Image")
         # self.image_btn.pack(side="left", padx=0, pady=0)
+        self.style_opt_btn = ttk.Menubutton(self.top_bar, text="Editor Style")
+        self.style_opt_btn.pack(side="left", padx=0, pady=0)
+        self.style_menu = ttk.Menu(self.style_opt_btn, tearoff=False)
+        self.style_menu.add_command(label='default', command=lambda: self.load_style('default'))
+        self.style_menu.add_command(label='emacs', command=lambda: self.load_style('emacs'))
+        self.style_menu.add_command(label='friendly', command=lambda: self.load_style('friendly'))
+        self.style_menu.add_command(label='friendly_grayscale', command=lambda: self.load_style('friendly_grayscale'))
+        self.style_menu.add_command(label='colorful', command=lambda: self.load_style('colorful'))
+        self.style_menu.add_command(label='autumn', command=lambda: self.load_style('autumn'))
+        self.style_menu.add_command(label='murphy', command=lambda: self.load_style('murphy'))
+        self.style_menu.add_command(label='manni', command=lambda: self.load_style('manni'))
+        self.style_menu.add_command(label='material', command=lambda: self.load_style('material'))
+        self.style_menu.add_command(label='monokai', command=lambda: self.load_style('monokai'))
+        self.style_menu.add_command(label='perldoc', command=lambda: self.load_style('perldoc'))
+        self.style_menu.add_command(label='pastie', command=lambda: self.load_style('pastie'))
+        self.style_menu.add_command(label='borland', command=lambda: self.load_style('borland'))
+        self.style_menu.add_command(label='trac', command=lambda: self.load_style('trac'))
+        self.style_menu.add_command(label='native', command=lambda: self.load_style('native'))
+        self.style_menu.add_command(label='fruity', command=lambda: self.load_style('fruity'))
+        self.style_menu.add_command(label='bw', command=lambda: self.load_style('bw'))
+        self.style_menu.add_command(label='vim', command=lambda: self.load_style('vim'))
+        self.style_menu.add_command(label='vs', command=lambda: self.load_style('vs'))
+        self.style_menu.add_command(label='tango', command=lambda: self.load_style('tango'))
+        self.style_menu.add_command(label='rrt', command=lambda: self.load_style('rrt'))
+        self.style_menu.add_command(label='xcode', command=lambda: self.load_style('xcode'))
+        self.style_menu.add_command(label='igor', command=lambda: self.load_style('igor'))
+        self.style_menu.add_command(label='paraiso-light', command=lambda: self.load_style('paraiso-light'))
+        self.style_menu.add_command(label='paraiso-dark', command=lambda: self.load_style('paraiso-dark'))
+        self.style_menu.add_command(label='lovelace', command=lambda: self.load_style('lovelace'))
+        self.style_menu.add_command(label='algol', command=lambda: self.load_style('algol'))
+        self.style_menu.add_command(label='algol_nu', command=lambda: self.load_style('algol_nu'))
+        self.style_menu.add_command(label='arduino', command=lambda: self.load_style('arduino'))
+        self.style_menu.add_command(label='rainbow_dash', command=lambda: self.load_style('rainbow_dash'))
+        self.style_menu.add_command(label='abap', command=lambda: self.load_style('abap'))
+        self.style_menu.add_command(label='solarized-dark', command=lambda: self.load_style('solarized-dark'))
+        self.style_menu.add_command(label='solarized-light', command=lambda: self.load_style('solarized-light'))
+        self.style_menu.add_command(label='sas', command=lambda: self.load_style('sas'))
+        self.style_menu.add_command(label='stata', command=lambda: self.load_style('stata'))
+        self.style_menu.add_command(label='stata-light', command=lambda: self.load_style('stata-light'))
+        self.style_menu.add_command(label='stata-dark', command=lambda: self.load_style('stata-dark'))
+        self.style_menu.add_command(label='inkpot', command=lambda: self.load_style('inkpot'))
+        self.style_menu.add_command(label='zenburn', command=lambda: self.load_style('zenburn'))
+        self.style_menu.add_command(label='gruvbox-dark', command=lambda: self.load_style('gruvbox-dark'))
+        self.style_menu.add_command(label='gruvbox-light', command=lambda: self.load_style('gruvbox-light'))
+        self.style_menu.add_command(label='dracula', command=lambda: self.load_style('dracula'))
+        self.style_menu.add_command(label='one-dark', command=lambda: self.load_style('one-dark'))
+        self.style_menu.add_command(label='lilypond', command=lambda: self.load_style('lilypond'))
+        self.style_opt_btn["menu"] = self.style_menu
         self.top_bar.pack(side="top", fill="x")
 
         # Creating the widgets
@@ -97,7 +157,7 @@ class EditorFrame(ttk.Frame):
 
         # Set Pygments syntax highlighting style.
         self.lexer = Lexer()
-        self.syntax_highlighting_tags = self.load_style("monokai")
+        self.syntax_highlighting_tags = self.load_style("stata-dark")
         # Default markdown string.
         default_text = constants.default_md_string
         self.text_area.insert(0.0, default_text)
@@ -119,6 +179,7 @@ class EditorFrame(ttk.Frame):
 
         # Bind mouse/key events to functions.
         self.text_area.bind("<<Modified>>", self.on_input_change)
+        self.text_area.edit_modified(0) #resets the text widget to generate another event when another change occours
         self.text_area.bind_all("<Control-f>", self.find)
         self.text_area.bind_all("<Control-a>", self.select_all)
         self.text_area.bind("<Button-3>", self.popup)
@@ -129,7 +190,7 @@ class EditorFrame(ttk.Frame):
 
     def popup(self, event):
         """Right-click popup at mouse location."""
-        self.right_click.post(event.x_root, event.y_root)
+        self.right_click.tk_popup(event.x_root, event.y_root)
 
     def on_scrollbar(self, *args):
         '''Scrolls both text widgets when the scrollbar is moved'''
@@ -208,9 +269,9 @@ class EditorFrame(ttk.Frame):
         markdownText = self.text_area.get("1.0", END)
         html = md2html.convert(markdownText)
         self.preview_area.load_html(html)
-        self.preview_area.add_css("body {background-color: #272822; color: white;}")
+        self.preview_area.add_css(self.css)
         self.check_markdown(start="1.0", end=END)
-        self.text_area.edit_modified(0)
+        self.text_area.edit_modified(0) #resets the text widget to generate another event when another change occours
 
     def load_style(self, stylename):
         """Load Pygments style for syntax highlighting within the editor."""
@@ -234,6 +295,11 @@ class EditorFrame(ttk.Frame):
                         selectbackground=self.style.highlight_color)
         self.text_area.tag_configure(str(Generic.StrongEmph), font=('Monospace', 10, 'bold', 'italic'))
         self.syntax_highlighting_tags.append(str(Generic.StrongEmph))
+        self.css = 'body {background-color: %s; color: %s}' % (
+            self.style.background_color,
+            self.text_area.tag_cget("Token.Text", "foreground")
+            )#used string%interpolation here because f'string' interpolation is too annoying with embeded { and }
+        self.preview_area.add_css(self.css)
         return self.syntax_highlighting_tags    
 
     def check_markdown(self, start='insert linestart', end='insert lineend'):
@@ -253,16 +319,46 @@ class EditorFrame(ttk.Frame):
                 self.text_area.tag_add(str(t), "range_start", "range_end")
             self.text_area.mark_set("range_start", "range_end")
 
-    # def bold(self):
-    #     try:
-    #         self.cur_selection = self.text_area.selection_get()
-    #         print(self.cur_selection)
-    #         self.bold_selection = f"**{self.cur_selection}**"
-    #         self.text_area.delete(index1=SEL_FIRST, index2=SEL_LAST)
-    #         self.text_area.insert(INSERT, self.bold_selection)
-    #     except:
-    #         # self.text_area.insert(INSERT, "****")
-    #         pass
+    def apply_markdown_both_sides(self, md_syntax, md_ignore):
+        """
+        A generic, catch-all attempt to apply and remove markdown from either 
+        side of a selection.
+
+        :param md_syntax: Tuple of markdown strings to apply/remove.
+        :param md_ignore: Tuple of markdown strings to ignore.
+        """
+        self.md_syntax = md_syntax
+        self.md_ignore = md_ignore
+        try:
+            self.cur_selection = self.text_area.selection_get()
+            if len(self.md_syntax) == 2 and self.md_syntax[0] == "**" and self.md_syntax[1] == "__" and str(self.cur_selection)[1] != "*" and str(self.cur_selection)[1] != "_":
+                if str(self.cur_selection).startswith(self.md_syntax) == False and str(self.cur_selection).startswith(self.md_ignore) == False and str(self.cur_selection)[0] != "*" and str(self.cur_selection)[0] != "_":
+                    self.with_md_selection = f"{self.md_syntax[0]}{self.cur_selection}{self.md_syntax[0]}"
+                    self.text_area.delete(index1=SEL_FIRST, index2=SEL_LAST)
+                    self.text_area.insert(INSERT, self.with_md_selection)
+                    return
+                else:
+                    return
+            if str(self.cur_selection).startswith(self.md_syntax) == True and str(self.cur_selection).endswith(self.md_syntax) == True and str(self.cur_selection).startswith(self.md_ignore) == False:
+                self.without_md_selection = str(self.cur_selection).replace(self.md_syntax[0], "").replace(self.md_syntax[1], "")
+                self.text_area.delete(index1=SEL_FIRST, index2=SEL_LAST)
+                self.text_area.insert(INSERT, self.without_md_selection)
+                return
+            elif str(self.cur_selection).startswith(self.md_syntax) == True and str(self.cur_selection).startswith(self.md_ignore) == True:
+                return
+            elif str(self.cur_selection).startswith(self.md_syntax) == True and str(self.cur_selection).startswith(self.md_ignore) == False:
+                self.without_md_selection = str(self.cur_selection).replace(self.md_syntax[0], "").replace(self.md_syntax[1], "")
+                self.text_area.delete(index1=SEL_FIRST, index2=SEL_LAST)
+                self.text_area.insert(INSERT, self.without_md_selection)
+                return
+            elif str(self.cur_selection).startswith(self.md_syntax) == False and str(self.cur_selection).startswith(self.md_ignore) == False:
+                self.with_md_selection = f"{self.md_syntax[0]}{self.cur_selection}{self.md_syntax[0]}"
+                self.text_area.delete(index1=SEL_FIRST, index2=SEL_LAST)
+                self.text_area.insert(INSERT, self.with_md_selection)
+                return
+        except:
+            print("EXCEPTION: Application/removal of markdown formatting failed.")
+            pass
 
 class Lexer(MarkdownLexer):
     """Extend MarkdownLexer to add markup for bold-italic. This needs extending 
